@@ -22,7 +22,6 @@ from typing import (
 )
 
 from rx.core.typing import Observable
-from PIL import Image
 import numpy as np
 
 
@@ -513,7 +512,7 @@ class Frame(TypedDict):
 
 class VideoFrame(Protocol):
     metadata: FrameMetadata
-    image: Image.Image
+    image: Any
 
     def input_width(self) -> int: ...
     def input_height(self) -> int: ...
@@ -522,7 +521,7 @@ class VideoFrame(Protocol):
     def to_numpy(
         self, options: Optional[ImageOptions] = None
     ) -> np.ndarray[Any, Any]: ...
-    def to_image(self, options: Optional[ImageOptions] = None) -> Image.Image: ...
+    def to_image(self, options: Optional[ImageOptions] = None) -> Any: ...
 
 
 class CameraDevice(Protocol):
